yumwat
======

Wild card! Oddshocks writes a yum plugin!

Wat
---

When I use yum to update my system or install new packages, I sometimes spot a
package I am unfamiliar with, such as the ``mesa-dri-filesystem`` package I saw
the other day. In some graphical extensions of yum, a brief discription of the
package is listed under each package name. I figured I'd check out some docs on
writing yum plugins, to see if I could display a description under each package
name in the CLI updater. Then the Internet was like, "Yo, each yum plugin is a
single file, written in the Python programming language", and after I cleaned
up my brain which had EXPLODED out of my HEAD I made this repo and now we are
on a science adventure.

License
-------

GNU GPL v3+.

Installing
----------

Installation is easy! From the project directory (where this file is),
do the following.

Shell Script
************

I have written a bit of a shell script that does the above installation
for you. It is ``install.sh``, and will probably require root privs, like
so: ``sudo ./install.sh``. Currently, it does not do step 3 below,
so make sure to do that yourself.

Manual Installation
*******************

1.  Install the plugin file: ``sudo cp yumwat.py /usr/lib/yum-plugins/``

2.  Install the plugin's configuration file: ``sudo cp yumwat.conf
    /etc/yum/pluginconf.d/``

3.  Add the line ``pluginpath=/usr/lib/yum-plugins`` to the file
    ``/etc/yum.conf``.

Timid mode
----------

The ``yumwat.conf`` file contains the line ``timid=0``. If timid is
set to 0, timid mode is off, and yumwat will print output unless
the ``--nowat`` option is used with yum. If timid is set to 1,
timid mode is on, and yumwat will not print output unless the
``--wat`` option is used with yum.

See below for how to easily enable or disable timid mode.

Enabling and Disabling
----------------------

**Enable yumwat** -- ``sudo /usr/lib/yum-plugins/yumwat.py enable``

**Disable yumwat** -- ``sudo /usr/lib/yum-plugins/yumwat.py disable``

**Enable timid mode** -- ``sudo /usr/lib/yum-plugins/yumwat.py timid``

**Disable timid mode** -- ``sudo /usr/lib/yum-plugins/yumwat.py assertive``

Uninstalling
------------

Easier than installation! We just need to make sure you remove the
generated bytecode file, too. You can do this by running the uninstall
script packaged with this plugin with root privs::

    sudo ./uninstall.sh

Otherwise, follow these steps:

1.  Remove the configuration file: ``sudo rm /etc/yum/pluginconf.d/yumwat.conf``

2.  Remove the plugin file and its generated bytecode: ``sudo rm
    /usr/lib/yum-plugins/yumwat.{py,pyc}``
